AgentCapability

Enum AgentCapability 

pub enum AgentCapability {
Show 23 variants Focusable, Clickable, Scrollable { vertical: bool, horizontal: bool, }, TextInput { multiline: bool, max_length: Option<usize>, }, Selectable { multi_select: bool, item_count: usize, }, Expandable { expanded: bool, }, Draggable, DropTarget, Resizable { min_width: Option<f32>, min_height: Option<f32>, max_width: Option<f32>, max_height: Option<f32>, }, Animated { playing: bool, }, RangeEditable { min: f64, max: f64, step: Option<f64>, }, Toggleable { state: bool, }, Sortable { columns: Vec<String>, }, Filterable, Searchable, Copyable, HasTooltip, HasKeyBindings { bindings: Vec<(String, String)>, }, Minimizable, Maximizable, Closable, Zoomable { min_zoom: f32, max_zoom: f32, }, Custom(String),
}
A capability that a widget instance advertises.

Agents query capabilities to understand what interactions are possible with a given widget without trial-and-error.

Variants



Focusable

Widget can receive keyboard focus.



Clickable

Widget responds to mouse clicks.



Scrollable

Widget can be scrolled (vertical, horizontal, or both).

Fields

vertical: bool
horizontal: bool


TextInput

Widget accepts text input.

Fields

multiline: bool
max_length: Option<usize>


Selectable

Widget supports item selection (single or multi).

Fields

multi_select: bool
item_count: usize


Expandable

Widget can be expanded or collapsed.

Fields

expanded: bool


Draggable

Widget supports drag-and-drop as a source.



DropTarget

Widget acts as a drop target.



Resizable

Widget supports resizing by the user.

Fields

min_width: Option<f32>
min_height: Option<f32>
max_width: Option<f32>
max_height: Option<f32>


Animated

Widget has an animation in progress.

Fields

playing: bool


RangeEditable

Widget supports value editing within a range.

Fields

min: f64
max: f64
step: Option<f64>


Toggleable

Widget can be toggled on/off.

Fields

state: bool


Sortable

Widget supports sorting.

Fields

columns: Vec<String>


Filterable

Widget supports filtering.



Searchable

Widget supports search.



Copyable

Widget supports copy-to-clipboard.



HasTooltip

Widget provides hover tooltips.



HasKeyBindings

Widget supports keyboard shortcuts.

Fields

bindings: Vec<(String, String)>


Minimizable

Widget can be minimized.



Maximizable

Widget can be maximized.



Closable

Widget can be closed.



Zoomable

Widget supports pinch-to-zoom.

Fields

min_zoom: f32
max_zoom: f32


Custom(String)

Custom capability with a name tag.

Implementations

Source

impl AgentCapability

pub fn name(&self) -> &str

Returns the canonical name of this capability for querying.