Frame

Struct Frame 

pub struct Frame<'a> {
    pub area: Rect,
    pub hit_map: &'a mut HitMap,
    /* private fields */
}
A rendering frame — abstraction over the GUI backend.

During Model::view, the frame provides methods to draw widgets and manage the UI tree for agent discoverability.

Fields

area: Rect

The available drawing area.

hit_map: &'a mut HitMap

The hit map for mouse routing.

Implementations

Source

impl<'a> Frame<'a>

pub fn new( area: Rect, hit_map: &'a mut HitMap, painter: &'a mut dyn Painter, ) -> Self

Create a new frame with the given area, hit map, and painter.

pub fn painter(&mut self) -> &mut dyn Painter

Get a mutable reference to the painter for this frame.

Examples found in repository?
examples/hello_agpu.rs (line 44)
31    fn view(&self, frame: &mut Frame<'_>) {
32        let area = frame.area;
33        let btn_y = area.y + 50.0;
34        let dec_rect = Rect::new(area.x + 10.0, btn_y, 80.0, 36.0);
35        let inc_rect = Rect::new(area.x + 100.0, btn_y, 80.0, 36.0);
36
37        // Paint everything first
38        {
39            let style = TextStyle {
40                font_size: 24.0,
41                color: Color::WHITE,
42                ..Default::default()
43            };
44            let p = frame.painter();
45
46            // Background
47            p.fill_rect(area, Color::rgba(0.1, 0.1, 0.12, 1.0), 0.0);
48
49            // Counter label
50            p.text(
51                Position::new(area.x + 10.0, area.y + 8.0),
52                &format!("Count: {}", self.count),
53                &style,
54            );
55
56            // Decrement button
57            p.fill_rect(dec_rect, Color::rgba(0.8, 0.2, 0.2, 1.0), 4.0);
58            p.text(
59                Position::new(dec_rect.x + 30.0, dec_rect.y + 6.0),
60                "−",
61                &style,
62            );
63
64            // Increment button
65            p.fill_rect(inc_rect, Color::rgba(0.2, 0.6, 0.2, 1.0), 4.0);
66            p.text(
67                Position::new(inc_rect.x + 30.0, inc_rect.y + 6.0),
68                "+",
69                &style,
70            );
71        }
72
73        // Register hitboxes for event routing
74        frame.register_hitbox("decrement_btn", dec_rect, 0);
75        frame.register_hitbox("increment_btn", inc_rect, 0);
76    }
pub fn register_widget(&mut self, node: UiNode)

Register a widget in the UI tree for agent discoverability.

pub fn register_hitbox( &mut self, agent_id: impl Into<String>, bounds: Rect, z_order: u32, )

Register a hitbox for mouse event routing.

Examples found in repository?
examples/hello_agpu.rs (line 74)
31    fn view(&self, frame: &mut Frame<'_>) {
32        let area = frame.area;
33        let btn_y = area.y + 50.0;
34        let dec_rect = Rect::new(area.x + 10.0, btn_y, 80.0, 36.0);
35        let inc_rect = Rect::new(area.x + 100.0, btn_y, 80.0, 36.0);
36
37        // Paint everything first
38        {
39            let style = TextStyle {
40                font_size: 24.0,
41                color: Color::WHITE,
42                ..Default::default()
43            };
44            let p = frame.painter();
45
46            // Background
47            p.fill_rect(area, Color::rgba(0.1, 0.1, 0.12, 1.0), 0.0);
48
49            // Counter label
50            p.text(
51                Position::new(area.x + 10.0, area.y + 8.0),
52                &format!("Count: {}", self.count),
53                &style,
54            );
55
56            // Decrement button
57            p.fill_rect(dec_rect, Color::rgba(0.8, 0.2, 0.2, 1.0), 4.0);
58            p.text(
59                Position::new(dec_rect.x + 30.0, dec_rect.y + 6.0),
60                "−",
61                &style,
62            );
63
64            // Increment button
65            p.fill_rect(inc_rect, Color::rgba(0.2, 0.6, 0.2, 1.0), 4.0);
66            p.text(
67                Position::new(inc_rect.x + 30.0, inc_rect.y + 6.0),
68                "+",
69                &style,
70            );
71        }
72
73        // Register hitboxes for event routing
74        frame.register_hitbox("decrement_btn", dec_rect, 0);
75        frame.register_hitbox("increment_btn", inc_rect, 0);
76    }
pub fn take_nodes(&mut self) -> Vec<UiNode>

Take the collected UI nodes (consumed by the runtime after rendering).