Module text

Module text 

Text rendering via glyphon โ€” GPU-accelerated glyph rasterisation.

Wraps the glyphon library to provide measure and draw operations compatible with the agpu Painter trait. Each frame the text renderer collects layout requests, then flushes them in one call.

Structs

TextEngine
GPU text renderer backed by glyphon.