#[repr(C)]pub enum PrimitiveTopology {
PointList = 0,
LineList = 1,
LineStrip = 2,
TriangleList = 3,
TriangleStrip = 4,
}Expand description
Primitive type the input mesh is composed of.
Corresponds to WebGPU GPUPrimitiveTopology.
Variants
PointList = 0
Vertex data is a list of points. Each vertex is a new point.
LineList = 1
Vertex data is a list of lines. Each pair of vertices composes a new line.
Vertices 0 1 2 3 create two lines 0 1 and 2 3
LineStrip = 2
Vertex data is a strip of lines. Each set of two adjacent vertices form a line.
Vertices 0 1 2 3 create three lines 0 1, 1 2, and 2 3.
TriangleList = 3
Vertex data is a list of triangles. Each set of 3 vertices composes a new triangle.
Vertices 0 1 2 3 4 5 create two triangles 0 1 2 and 3 4 5
TriangleStrip = 4
Vertex data is a triangle strip. Each set of three adjacent vertices form a triangle.
Vertices 0 1 2 3 4 5 create four triangles 0 1 2, 2 1 3, 2 3 4, and 4 3 5
Implementations