pub struct TextEngine {
pub font_system: FontSystem,
pub swash_cache: SwashCache,
pub atlas: TextAtlas,
pub viewport: Viewport,
pub renderer: TextRenderer,
/* private fields */
}Expand description
GPU text renderer backed by glyphon.
Fields
font_system: FontSystemswash_cache: SwashCacheatlas: TextAtlasviewport: Viewportrenderer: TextRendererImplementations
Sourceimpl TextEngine
impl TextEngine
Sourcepub fn new(gpu: &GpuContext, format: TextureFormat) -> Self
pub fn new(gpu: &GpuContext, format: TextureFormat) -> Self
Create a new text engine for the given GPU context and surface format.
Sourcepub fn with_msaa(
gpu: &GpuContext,
format: TextureFormat,
msaa_samples: u32,
) -> Self
pub fn with_msaa( gpu: &GpuContext, format: TextureFormat, msaa_samples: u32, ) -> Self
Create a text engine with the given MSAA sample count.
Sourcepub fn draw(
&mut self,
pos: Position,
text: &str,
style: &TextStyle,
clip: Option<Rect>,
)
pub fn draw( &mut self, pos: Position, text: &str, style: &TextStyle, clip: Option<Rect>, )
Queue text to be drawn at the given position.
Sourcepub fn flush(
&mut self,
gpu: &GpuContext,
pass: &mut RenderPass<'_>,
width: u32,
height: u32,
)
pub fn flush( &mut self, gpu: &GpuContext, pass: &mut RenderPass<'_>, width: u32, height: u32, )
Flush all pending text draws into the render pass.