Core GPU types — agpu’s own type system replacing direct wgpu dependency.
Users depend on agpu instead of wgpu. Every type is defined or
re-exported here so that downstream crates never need wgpu in their
Cargo.toml.
Structs
- Backends
- Represents the backends that wgpu will use.
- Blend
Component - Describes a blend component of a
BlendState. - Blend
State - Describe the blend state of a render pipeline,
within
ColorTargetState. - Buffer
Usages - Different ways that you can use a buffer.
- Color
- RGBA double precision color.
- Color
Target State - Describes the color state of a render pipeline.
- Color
Writes - Color write mask. Disabled color channels will not be written to.
- Depth
Bias State - Describes the biasing setting for the depth target.
- Depth
Stencil State - Describes the depth/stencil state in a render pipeline.
- Device
- Open connection to a graphics and/or compute device.
- Extent3d
- Extent of a texture related operation.
- Features
- Features that are not guaranteed to be supported.
- GpuBuffer
Descriptor - Describes how to create a GPU buffer.
- GpuSampler
Descriptor - Describes how to create a GPU sampler.
- GpuTexture
Descriptor - Describes how to create a GPU texture.
- Instance
- Context for all other wgpu objects. Instance of wgpu.
- Instance
Descriptor - Options for creating an instance.
- Limits
- Represents the sets of limits an adapter/device supports.
- Multisample
State - Describes the multi-sampling state of a render pipeline.
- Operations
- Pair of load and store operations for an attachment aspect.
- Origin3d
- Origin of a copy to/from a texture.
- Pipeline
Compilation Options - Advanced options for use when a pipeline is compiled
- Primitive
State - Describes the state of primitive assembly and rasterization in a render pipeline.
- Queue
- Handle to a command queue on a device.
- Render
Pass Color Attachment - Describes a color attachment to a
RenderPass. - Render
Pass Depth Stencil Attachment - Describes a depth/stencil attachment to a
RenderPass. - Render
Pass Descriptor - Describes the attachments of a render pass.
- Render
Pass Timestamp Writes - Describes the timestamp writes of a render pass.
- Shader
Stages - Describes the shader stages that a binding will be visible from.
- Stencil
Face State - Describes stencil state in a render pipeline.
- Stencil
State - State of the stencil operation (fixed-pipeline stage).
- Surface
- Handle to a presentable surface.
- Texture
Usages - Different ways that you can use a texture.
- Texture
View - Handle to a texture view.
- Vertex
Attribute - Vertex inputs (attributes) to shaders.
- Vertex
Buffer Layout - Describes how the vertex buffer is interpreted.
Enums
- Address
Mode - How edges should be handled in texture addressing.
- Backend
Preference - Backend preference for GPU initialisation.
- Binding
Type - Specific type of a binding.
- Blend
Factor - Alpha blend factor.
- Blend
Operation - Alpha blend operation.
- Buffer
Binding Type - Specific type of a buffer binding.
- Compare
Function - Comparison function used for depth and stencil operations.
- Face
- Face of a vertex.
- Filter
Mode - Texel mixing mode when sampling between texels.
- Front
Face - Vertex winding order which classifies the “front” face of a triangle.
- GpuResource
Kind - GPU resource kind — used by the resource tracker and ontology.
- Index
Format - Format of indices used with pipeline.
- LoadOp
- Operation to perform to the output attachment at the start of a render pass.
- MapMode
- Type of buffer mapping.
- Memory
Hints - Hints to the device about the memory allocation strategy.
- Polygon
Mode - Type of drawing mode for polygons
- Power
Preference - Power Preference when choosing a physical adapter.
- Present
Mode - Behavior of the presentation engine based on frame rate.
- Primitive
Topology - Primitive type the input mesh is composed of.
- Sampler
Binding Type - Specific type of a sampler binding.
- Shader
Source - Source of a shader module.
- Stencil
Operation - Operation to perform on the stencil value.
- Storage
Texture Access - Specific type of a sample in a texture binding.
- StoreOp
- Operation to perform to the output attachment at the end of a render pass.
- Surface
Error - Result of an unsuccessful call to
Surface::get_current_texture. - Texture
Aspect - Kind of data the texture holds.
- Texture
Dimension - Dimensionality of a texture.
- Texture
Format - Underlying texture data format.
- Texture
Sample Type - Specific type of a sample in a texture binding.
- Texture
View Dimension - Dimensions of a particular texture view.
- Vertex
Format - Vertex Format for a
VertexAttribute(input). - Vertex
Step Mode - Whether a vertex buffer is indexed by vertex or by instance.
Type Aliases
- Buffer
Address - Integral type used for buffer offsets.
- Buffer
Size - Integral type used for buffer slice sizes.
- Command
Encoder Descriptor - Describes a
CommandEncoder. - Maintain
- Passed to
Device::pollto control how and if it should block. - Surface
Configuration - Describes a
Surface. - Texture
Descriptor - Describes a
Texture. - Texture
View Descriptor - Describes a
TextureView.